@@ -1,7 +1,7 @@
 package Perinci::To::POD;
 
-our $DATE = '2016-04-18'; # DATE
-our $VERSION = '0.78'; # VERSION
+our $DATE = '2016-09-26'; # DATE
+our $VERSION = '0.79'; # VERSION
 
 use 5.010001;
 use Log::Any::IfLOG '$log';
@@ -139,11 +139,11 @@ sub gen_doc_section_links {
             my $link = ref($link0) ? $link0 : {url=>$link0};
             my $url = $link->{url};
             next if $seen_urls{$url}++;
-            $url =~ s!\Apm:!!;
+            $url =~ s!\A(pm|prog):(//?)?!!;
             $self->add_doc_lines(
-                "L<$url>" .
-                    ($link->{summary} ? ", $link->{summary}." : "") .
-                    ($link->{description} ? ". " . $self->_md2pod($link->{description}) : ""),
+                "L<$url>." .
+                    ($link->{summary} ? " $link->{summary}." : "") .
+                    ($link->{description} ? " " . $self->_md2pod($link->{description}) : ""),
                 "");
         }
     }
@@ -164,7 +164,7 @@ Perinci::To::POD - Generate POD documentation for a package from Rinci metadata
 
 =head1 VERSION
 
-This document describes version 0.78 of Perinci::To::POD (from Perl distribution Perinci-To-Doc), released on 2016-04-18.
+This document describes version 0.79 of Perinci::To::POD (from Perl distribution Perinci-To-Doc), released on 2016-09-26.
 
 =head1 SYNOPSIS
 
